@@ -50,6 +50,63 @@ class BasicElement():
     def cascade_create(self):
         return False
 
+    def createMany(self):
+        # try:
+        self.date_created= datetime.datetime.utcnow()
+        self.date_updated = self.date_created
+        self.deleted = self.get('deleted', False)
+        if self.deleted == None:
+            self.deleted = False
+        for val in self.values:
+            val['date_created'] = self.date_created
+            val['date_updated'] = self.date_updated
+            val['deleted'] = self.deleted
+            for key in self.attributes:
+                if key in val and val[key] == None:
+                    val.pop(key)
+            if self.isEdge() == True:
+                from_to = self.vertex()
+                if self.get('_to') != None:
+                    val['_to'] = f'{from_to["_to"]}/{val.get("_to")}'
+                if self.get('_from') != None:
+                    val['_from'] = f'{from_to["_from"]}/{val.get("_from")}'
+        aql = f'for nd IN {json.dumps(self.values)} \
+            INSERT nd into {self.get_collection()} \
+            LET inserted = NEW \
+            RETURN inserted._key'
+        res = self.db.AQLQuery(aql, rawResults=True, batchSize=100000)
+        for i,val in enumerate(self.values):
+            val['_key'] = res[i]
+        # except:
+        #     res = None
+        #     self.status = False
+        self.status = res != None
+        
+    def wipeByFilter(self):
+        # try:
+        attribute_dict = self.to_dict()
+        attribute_list = [{'val':attribute_dict[att] , 'dim': att, 'op':'=='} for att in attribute_dict if attribute_dict[att] != None ]
+        filters_list = []
+        for att in attribute_list:
+            if isinstance(att['val'], str):
+                if att["op"] == '=~':
+                    filters_list.append(f'Regex_Test(m.`{att["dim"]}`,"{att["val"]}", true)')
+                else:
+                    filters_list.append(f'm.`{att["dim"]}` {att["op"]} "{att["val"]}"')
+            else:
+                filters_list.append(f'm.`{att["dim"]}` {att["op"]} {att["val"]}')
+        qf = ' and '.join(filters_list)
+        query = 'for m in '+ self.get_collection() +'\
+                FILTER '+qf+'\
+                REMOVE m in '+ self.get_collection()
+        res = self.db.AQLQuery(query, rawResults=True, batchSize=100)
+        print('res')
+        print(res)
+        # except:
+        #     self._key = None
+        #     self.status = False
+        #     self.found = []
+
     def create(self):
         try:
             self.date_created= datetime.datetime.utcnow()
@@ -248,34 +305,49 @@ class BasicElement():
             return False
         return before != after
 
-    def __init__(self, mode, data = None):
+    def __init__(self, mode, data = None, multi = False):
         # try:
         self.db = self.db_client[self.db_name]
         self.make()
-        for key in self.attributes:
-            setattr(self, key, data[key] if key in data else None)
-        if mode == 'create': # OK
-            self.status = self.create()
-        elif mode == 'update': # OK
-            self.status = self.update()
-        elif mode == 'set': # OK
-            self.status = True
-        elif mode == 'find':  # OK
-            self.find()
-        elif mode == 'fetch':  # OK
-            self.findGraph(data)
-        elif mode == 'fetch_exact':  # OK
-            self.findGraph(data, avoid_regex=True)
-        elif mode == 'delete': # OK
-            self.delete()
-        elif mode == 'publish': # OK
-            self.status = self.do_publish(data['publish'])
-        elif mode == 'auth': # OK
-            self.auth()
-        elif mode == 'search': # OK
-            self.search(data)
-        elif mode == 'limited_search': # OK
-            self.search(data.pop('query', None), data.pop('limit', None))
+        if multi == True:
+            self.values = []
+            for i,val in enumerate(data):
+                temp_val = {}
+                for key in self.attributes:
+                    temp_val[key] =val[key] if key in val else None
+                self.values.append(temp_val)         
+            if mode == 'create': # OK
+                self.status = self.createMany()      
+            # if mode == 'delete': # OK
+            #     self.status = self.deleteMany()        
+        else:    
+            for key in self.attributes:
+                setattr(self, key, data[key] if key in data else None)
+            if mode == 'create': # OK
+                self.status = self.create()
+            elif mode == 'update': # OK
+                self.status = self.update()
+            elif mode == 'set': # OK
+                self.status = True
+            elif mode == 'find':  # OK
+                self.find()
+            elif mode == 'fetch':  # OK
+                self.findGraph(data)
+            elif mode == 'fetch_exact':  # OK
+                self.findGraph(data, avoid_regex=True)
+            elif mode == 'delete': # OK
+                self.delete()
+            elif mode == 'wipe_filter': # OK
+                self.wipeByFilter()
+            elif mode == 'publish': # OK
+                self.status = self.do_publish(data['publish'])
+            elif mode == 'auth': # OK
+                self.auth()
+            elif mode == 'search': # OK
+                self.search(data)
+            elif mode == 'limited_search': # OK
+                self.search(data.pop('query', None), data.pop('limit', None))
+        
         # except:
         #     print("Unexpected error.")
         #     self._key = None
